@@ -8,9 +8,10 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf/plugins/parsers"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/require"
 )
 
 func TestCSVGZImport(t *testing.T) {
@@ -49,15 +50,20 @@ func TestCSVGZImport(t *testing.T) {
 	// Write csv file to process into the 'process' directory.
 	f, err := os.Create(filepath.Join(processDirectory, testCsvFile))
 	require.NoError(t, err)
-	f.WriteString("thing,color\nsky,blue\ngrass,green\nclifford,red\n")
-	f.Close()
+	_, err = f.WriteString("thing,color\nsky,blue\ngrass,green\nclifford,red\n")
+	require.NoError(t, err)
+	err = f.Close()
+	require.NoError(t, err)
 
 	// Write csv.gz file to process into the 'process' directory.
 	var b bytes.Buffer
 	w := gzip.NewWriter(&b)
-	w.Write([]byte("thing,color\nsky,blue\ngrass,green\nclifford,red\n"))
-	w.Close()
+	_, err = w.Write([]byte("thing,color\nsky,blue\ngrass,green\nclifford,red\n"))
+	require.NoError(t, err)
+	err = w.Close()
+	require.NoError(t, err)
 	err = ioutil.WriteFile(filepath.Join(processDirectory, testCsvGzFile), b.Bytes(), 0666)
+	require.NoError(t, err)
 
 	// Start plugin before adding file.
 	err = r.Start(&acc)
@@ -72,21 +78,15 @@ func TestCSVGZImport(t *testing.T) {
 
 	// File should have gone back to the test directory, as we configured.
 	_, err = os.Stat(filepath.Join(finishedDirectory, testCsvFile))
-	_, err = os.Stat(filepath.Join(finishedDirectory, testCsvGzFile))
-
 	require.NoError(t, err)
-}
 
-// For JSON data.
-type event struct {
-	Name   string
-	Speed  float64
-	Length float64
+	_, err = os.Stat(filepath.Join(finishedDirectory, testCsvGzFile))
+	require.NoError(t, err)
 }
 
 func TestMultipleJSONFileImports(t *testing.T) {
 	acc := testutil.Accumulator{}
-	testJsonFile := "test.json"
+	testJSONFile := "test.json"
 
 	// Establish process directory and finished directory.
 	finishedDirectory, err := ioutil.TempDir("", "finished")
@@ -117,10 +117,12 @@ func TestMultipleJSONFileImports(t *testing.T) {
 
 	// Let's drop a 5-line LINE-DELIMITED json.
 	// Write csv file to process into the 'process' directory.
-	f, err := os.Create(filepath.Join(processDirectory, testJsonFile))
+	f, err := os.Create(filepath.Join(processDirectory, testJSONFile))
+	require.NoError(t, err)
+	_, err = f.WriteString("{\"Name\": \"event1\",\"Speed\": 100.1,\"Length\": 20.1}\n{\"Name\": \"event2\",\"Speed\": 500,\"Length\": 1.4}\n{\"Name\": \"event3\",\"Speed\": 200,\"Length\": 10.23}\n{\"Name\": \"event4\",\"Speed\": 80,\"Length\": 250}\n{\"Name\": \"event5\",\"Speed\": 120.77,\"Length\": 25.97}")
+	require.NoError(t, err)
+	err = f.Close()
 	require.NoError(t, err)
-	f.WriteString("{\"Name\": \"event1\",\"Speed\": 100.1,\"Length\": 20.1}\n{\"Name\": \"event2\",\"Speed\": 500,\"Length\": 1.4}\n{\"Name\": \"event3\",\"Speed\": 200,\"Length\": 10.23}\n{\"Name\": \"event4\",\"Speed\": 80,\"Length\": 250}\n{\"Name\": \"event5\",\"Speed\": 120.77,\"Length\": 25.97}")
-	f.Close()
 
 	err = r.Start(&acc)
 	r.Log = testutil.Logger{}
