@@ -51,7 +51,8 @@ go_goroutines 15 1490802350000
 
 func TestPrometheusGeneratesMetrics(t *testing.T) {
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		fmt.Fprintln(w, sampleTextFormat)
+		_, err := fmt.Fprintln(w, sampleTextFormat)
+		require.NoError(t, err)
 	}))
 	defer ts.Close()
 
@@ -76,7 +77,8 @@ func TestPrometheusGeneratesMetrics(t *testing.T) {
 
 func TestPrometheusGeneratesMetricsWithHostNameTag(t *testing.T) {
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		fmt.Fprintln(w, sampleTextFormat)
+		_, err := fmt.Fprintln(w, sampleTextFormat)
+		require.NoError(t, err)
 	}))
 	defer ts.Close()
 
@@ -107,7 +109,8 @@ func TestPrometheusGeneratesMetricsAlthoughFirstDNSFailsIntegration(t *testing.T
 	}
 
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		fmt.Fprintln(w, sampleTextFormat)
+		_, err := fmt.Fprintln(w, sampleTextFormat)
+		require.NoError(t, err)
 	}))
 	defer ts.Close()
 
@@ -130,7 +133,8 @@ func TestPrometheusGeneratesMetricsAlthoughFirstDNSFailsIntegration(t *testing.T
 
 func TestPrometheusGeneratesSummaryMetricsV2(t *testing.T) {
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		fmt.Fprintln(w, sampleSummaryTextFormat)
+		_, err := fmt.Fprintln(w, sampleSummaryTextFormat)
+		require.NoError(t, err)
 	}))
 	defer ts.Close()
 
@@ -149,7 +153,6 @@ func TestPrometheusGeneratesSummaryMetricsV2(t *testing.T) {
 	assert.True(t, acc.HasFloatField("prometheus", "go_gc_duration_seconds_sum"))
 	assert.True(t, acc.HasFloatField("prometheus", "go_gc_duration_seconds_count"))
 	assert.True(t, acc.TagValue("prometheus", "url") == ts.URL+"/metrics")
-
 }
 
 func TestSummaryMayContainNaN(t *testing.T) {
@@ -161,7 +164,8 @@ go_gc_duration_seconds_sum 42.0
 go_gc_duration_seconds_count 42
 `
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		fmt.Fprintln(w, data)
+		_, err := fmt.Fprintln(w, data)
+		require.NoError(t, err)
 	}))
 	defer ts.Close()
 
@@ -217,7 +221,8 @@ go_gc_duration_seconds_count 42
 
 func TestPrometheusGeneratesGaugeMetricsV2(t *testing.T) {
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		fmt.Fprintln(w, sampleGaugeTextFormat)
+		_, err := fmt.Fprintln(w, sampleGaugeTextFormat)
+		require.NoError(t, err)
 	}))
 	defer ts.Close()
 
@@ -260,25 +265,26 @@ func TestInitConfigErrors(t *testing.T) {
 
 	// Both invalid IP addresses
 	p.NodeIP = "10.240.0.0.0"
-	os.Setenv("NODE_IP", "10.000.0.0.0")
+	require.NoError(t, os.Setenv("NODE_IP", "10.000.0.0.0"))
 	err := p.Init()
-	expectedMessage := "The node_ip config and the environment variable NODE_IP are not set or invalid. Cannot get pod list for monitor_kubernetes_pods using node scrape scope"
-	assert.Equal(t, expectedMessage, err.Error())
-	os.Setenv("NODE_IP", "10.000.0.0")
+	require.Error(t, err)
+	expectedMessage := "the node_ip config and the environment variable NODE_IP are not set or invalid; cannot get pod list for monitor_kubernetes_pods using node scrape scope"
+	require.Equal(t, expectedMessage, err.Error())
+	require.NoError(t, os.Setenv("NODE_IP", "10.000.0.0"))
 
 	p.KubernetesLabelSelector = "label0==label0, label0 in (=)"
 	err = p.Init()
-	expectedMessage = "Error parsing the specified label selector(s): unable to parse requirement: found '=', expected: ',', ')' or identifier"
-	assert.Equal(t, expectedMessage, err.Error())
+	expectedMessage = "error parsing the specified label selector(s): unable to parse requirement: found '=', expected: ',', ')' or identifier"
+	require.Error(t, err, expectedMessage)
 	p.KubernetesLabelSelector = "label0==label"
 
 	p.KubernetesFieldSelector = "field,"
 	err = p.Init()
-	expectedMessage = "Error parsing the specified field selector(s): invalid selector: 'field,'; can't understand 'field'"
-	assert.Equal(t, expectedMessage, err.Error())
+	expectedMessage = "error parsing the specified field selector(s): invalid selector: 'field,'; can't understand 'field'"
+	require.Error(t, err, expectedMessage)
 
 	p.KubernetesFieldSelector = "spec.containerNames=containerNames"
 	err = p.Init()
-	expectedMessage = "The field selector spec.containerNames is not supported for pods"
-	assert.Equal(t, expectedMessage, err.Error())
+	expectedMessage = "the field selector spec.containerNames is not supported for pods"
+	require.Error(t, err, expectedMessage)
 }
